@@ -87,9 +87,8 @@ class ShortenerServer(Process):
     def has_and_not_none(d, keys) -> bool:
         dk = d.keys()
         for k in keys:
-            if k in dk and (d[k] != '' or d[k] is not None):
+            if k in dk and d[k] is None:
                 return False
-        log.debug(d)
         return True
 
     @staticmethod
@@ -111,7 +110,7 @@ class ShortenerServer(Process):
         }
 
         if self.qr:
-            e.qr = self.generate_qrcode(self.domain + e["suffix"])
+            e["qr"] = self.generate_qrcode(self.domain + e["suffix"])
         if "key" in data.keys():
             e["key"] = data["key"]
         if self.has_and_not_none(data, ["time", "unit"]):
