@@ -9,7 +9,6 @@ def main():
         formatter_class=ArgumentDefaultsHelpFormatter
     )
     ap.add_argument("-d", "--database", help="database to use", default="shrnk")
-    ap.add_argument("-s", "--statistics", help="show database statistics", action="store_true")
     ap.add_argument("-q", "--qr", help="Enable qr code generation", action="store_true")
     ap.add_argument("--salt", help="Hashids salt", default="666")
     ap.add_argument("--host", help="what do you think", default="127.0.0.1")
@@ -18,9 +17,6 @@ def main():
     ap.add_argument("--debug", help="enable debugging messages", action="store_true")
     a = ap.parse_args()
 
-    if a.statistics:
-        log.debug("Going to show statistics.")
-
     if a.domain is not None:
         if not a.domain.startswith('http://') and not a.domain.startswith('https://'):
             log.warning("Protocol not specified. Assuming https.")
@@ -28,6 +24,10 @@ def main():
         if not a.domain.endswith('/'):
             a.domain += "/"
 
+    if a.qr and not a.domain:
+        log.error("Can not use QR Code functionality without the servers TLD")
+        exit(0)
+
     log.debug("Initializing the ShortenerServer")
     server = ShortenerServer(a.database, a.salt, a.host, a.port, a.debug, a.domain, a.qr)
 
